Class: Google::Apis::BeyondcorpV1::GoogleCloudBeyondcorpAppconnectorsV1ResourceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/beyondcorp_v1/classes.rb,
lib/google/apis/beyondcorp_v1/representations.rb,
lib/google/apis/beyondcorp_v1/representations.rb

Overview

ResourceInfo represents the information or status of an app connector resource component that's used to report on various parts of the system. For example, ResourceInfo can be used to convey the status of a remote_agent, including the status of an appgateway for an runtime environment in a container instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudBeyondcorpAppconnectorsV1ResourceInfo

Returns a new instance of GoogleCloudBeyondcorpAppconnectorsV1ResourceInfo.



1212
1213
1214
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 1212

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Required. Unique Id for the resource. Corresponds to the JSON property id

Returns:

  • (String)


1188
1189
1190
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 1188

def id
  @id
end

#resourceHash<String,Object>

Specific details for the resource. This is for internal use only. Corresponds to the JSON property resource

Returns:

  • (Hash<String,Object>)


1193
1194
1195
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 1193

def resource
  @resource
end

#statusString

Overall health status. Overall status is derived based on the status of each sub level resources. Corresponds to the JSON property status

Returns:

  • (String)


1199
1200
1201
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 1199

def status
  @status
end

#subArray<Google::Apis::BeyondcorpV1::GoogleCloudBeyondcorpAppconnectorsV1ResourceInfo>

List of Info for the sub level resources. Corresponds to the JSON property sub



1204
1205
1206
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 1204

def sub
  @sub
end

#timeString

The timestamp to collect the info. It is suggested to be set by the topmost level resource only. Corresponds to the JSON property time

Returns:

  • (String)


1210
1211
1212
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 1210

def time
  @time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1217
1218
1219
1220
1221
1222
1223
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 1217

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @resource = args[:resource] if args.key?(:resource)
  @status = args[:status] if args.key?(:status)
  @sub = args[:sub] if args.key?(:sub)
  @time = args[:time] if args.key?(:time)
end