Class: Google::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1ProxyProtocolConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/beyondcorp_v1/classes.rb,
lib/google/apis/beyondcorp_v1/representations.rb,
lib/google/apis/beyondcorp_v1/representations.rb

Overview

The configuration for the proxy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudBeyondcorpSecuritygatewaysV1ProxyProtocolConfig

Returns a new instance of GoogleCloudBeyondcorpSecuritygatewaysV1ProxyProtocolConfig.



2158
2159
2160
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2158

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_client_headersArray<String>

Optional. List of the allowed client header names. Corresponds to the JSON property allowedClientHeaders

Returns:

  • (Array<String>)


2132
2133
2134
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2132

def allowed_client_headers
  @allowed_client_headers
end

#client_ipBoolean Also known as: client_ip?

Optional. Client IP configuration. The client IP address is included if true. Corresponds to the JSON property clientIp

Returns:

  • (Boolean)


2137
2138
2139
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2137

def client_ip
  @client_ip
end

#contextual_headersGoogle::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1ContextualHeaders

Contextual headers configuration. Corresponds to the JSON property contextualHeaders



2143
2144
2145
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2143

def contextual_headers
  @contextual_headers
end

#gateway_identityString

Optional. The security gateway identity configuration. Corresponds to the JSON property gatewayIdentity

Returns:

  • (String)


2148
2149
2150
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2148

def gateway_identity
  @gateway_identity
end

#metadata_headersHash<String,String>

Optional. Custom resource specific headers along with the values. The names should conform to RFC 9110: >Field names can contain alphanumeric characters, hyphens, and periods, can contain only ASCII-printable characters and tabs, and must start with a letter. Corresponds to the JSON property metadataHeaders

Returns:

  • (Hash<String,String>)


2156
2157
2158
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2156

def 
  @metadata_headers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2163
2164
2165
2166
2167
2168
2169
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2163

def update!(**args)
  @allowed_client_headers = args[:allowed_client_headers] if args.key?(:allowed_client_headers)
  @client_ip = args[:client_ip] if args.key?(:client_ip)
  @contextual_headers = args[:contextual_headers] if args.key?(:contextual_headers)
  @gateway_identity = args[:gateway_identity] if args.key?(:gateway_identity)
  @metadata_headers = args[:metadata_headers] if args.key?(:metadata_headers)
end