Class: Google::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1SecurityGateway

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/beyondcorp_v1/classes.rb,
lib/google/apis/beyondcorp_v1/representations.rb,
lib/google/apis/beyondcorp_v1/representations.rb

Overview

The information about a security gateway resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudBeyondcorpSecuritygatewaysV1SecurityGateway

Returns a new instance of GoogleCloudBeyondcorpSecuritygatewaysV1SecurityGateway.



2235
2236
2237
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2235

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2179
2180
2181
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2179

def create_time
  @create_time
end

#delegating_service_accountString

Output only. Service account used for operations that involve resources in consumer projects. Corresponds to the JSON property delegatingServiceAccount

Returns:

  • (String)


2185
2186
2187
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2185

def 
  @delegating_service_account
end

#display_nameString

Optional. An arbitrary user-provided name for the SecurityGateway. Cannot exceed 64 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


2191
2192
2193
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2191

def display_name
  @display_name
end

#external_ipsArray<String>

Output only. IP addresses that will be used for establishing connection to the endpoints. Corresponds to the JSON property externalIps

Returns:

  • (Array<String>)


2197
2198
2199
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2197

def external_ips
  @external_ips
end

#hubsHash<String,Google::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1Hub>

Optional. Map of Hubs that represents regional data path deployment with GCP region as a key. Corresponds to the JSON property hubs



2203
2204
2205
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2203

def hubs
  @hubs
end

#loggingGoogle::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1LoggingConfig

Configuration for Cloud Logging. Corresponds to the JSON property logging



2208
2209
2210
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2208

def logging
  @logging
end

#nameString

Identifier. Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


2213
2214
2215
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2213

def name
  @name
end

#proxy_protocol_configGoogle::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1ProxyProtocolConfig

The configuration for the proxy. Corresponds to the JSON property proxyProtocolConfig



2218
2219
2220
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2218

def proxy_protocol_config
  @proxy_protocol_config
end

#service_discoveryGoogle::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1ServiceDiscovery

Settings related to the Service Discovery. Corresponds to the JSON property serviceDiscovery



2223
2224
2225
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2223

def service_discovery
  @service_discovery
end

#stateString

Output only. The operational state of the SecurityGateway. Corresponds to the JSON property state

Returns:

  • (String)


2228
2229
2230
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2228

def state
  @state
end

#update_timeString

Output only. Timestamp when the resource was last modified. Corresponds to the JSON property updateTime

Returns:

  • (String)


2233
2234
2235
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2233

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2240

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delegating_service_account = args[:delegating_service_account] if args.key?(:delegating_service_account)
  @display_name = args[:display_name] if args.key?(:display_name)
  @external_ips = args[:external_ips] if args.key?(:external_ips)
  @hubs = args[:hubs] if args.key?(:hubs)
  @logging = args[:logging] if args.key?(:logging)
  @name = args[:name] if args.key?(:name)
  @proxy_protocol_config = args[:proxy_protocol_config] if args.key?(:proxy_protocol_config)
  @service_discovery = args[:service_discovery] if args.key?(:service_discovery)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end