Class: Google::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1alphaSecurityGatewayOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/beyondcorp_v1/classes.rb,
lib/google/apis/beyondcorp_v1/representations.rb,
lib/google/apis/beyondcorp_v1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudBeyondcorpSecuritygatewaysV1alphaSecurityGatewayOperationMetadata

Returns a new instance of GoogleCloudBeyondcorpSecuritygatewaysV1alphaSecurityGatewayOperationMetadata.



2414
2415
2416
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2414

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


2378
2379
2380
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2378

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2383
2384
2385
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2383

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


2388
2389
2390
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2388

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have been cancelled successfully have Operation. error value with a google.rpc.Status.code of 1, corresponding to Code. CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


2396
2397
2398
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2396

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


2402
2403
2404
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2402

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


2407
2408
2409
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2407

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


2412
2413
2414
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2412

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2419
2420
2421
2422
2423
2424
2425
2426
2427
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2419

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end