Class: Google::Apis::BeyondcorpV1::GoogleLongrunningListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/beyondcorp_v1/classes.rb,
lib/google/apis/beyondcorp_v1/representations.rb,
lib/google/apis/beyondcorp_v1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleLongrunningListOperationsResponse

Returns a new instance of GoogleLongrunningListOperationsResponse.



2872
2873
2874
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2872

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2857
2858
2859
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2857

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::BeyondcorpV1::GoogleLongrunningOperation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



2862
2863
2864
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2862

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2870
2871
2872
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2870

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2877
2878
2879
2880
2881
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2877

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end