Class: Google::Apis::BeyondcorpV1::Tunnelv1ProtoTunnelerInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/beyondcorp_v1/classes.rb,
lib/google/apis/beyondcorp_v1/representations.rb,
lib/google/apis/beyondcorp_v1/representations.rb

Overview

TunnelerInfo contains metadata about tunneler launched by connection manager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Tunnelv1ProtoTunnelerInfo

Returns a new instance of Tunnelv1ProtoTunnelerInfo.



3129
3130
3131
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 3129

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backoff_retry_countFixnum

backoff_retry_count stores the number of times the tunneler has been retried by tunManager for current backoff sequence. Gets reset to 0 if time difference between 2 consecutive retries exceeds backoffRetryResetTime. Corresponds to the JSON property backoffRetryCount

Returns:

  • (Fixnum)


3106
3107
3108
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 3106

def backoff_retry_count
  @backoff_retry_count
end

#idString

id is the unique id of a tunneler. Corresponds to the JSON property id

Returns:

  • (String)


3111
3112
3113
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 3111

def id
  @id
end

#latest_errGoogle::Apis::BeyondcorpV1::Tunnelv1ProtoTunnelerError

TunnelerError is an error proto for errors returned by the connection manager. Corresponds to the JSON property latestErr



3116
3117
3118
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 3116

def latest_err
  @latest_err
end

#latest_retry_timeString

latest_retry_time stores the time when the tunneler was last restarted. Corresponds to the JSON property latestRetryTime

Returns:

  • (String)


3121
3122
3123
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 3121

def latest_retry_time
  @latest_retry_time
end

#total_retry_countFixnum

total_retry_count stores the total number of times the tunneler has been retried by tunManager. Corresponds to the JSON property totalRetryCount

Returns:

  • (Fixnum)


3127
3128
3129
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 3127

def total_retry_count
  @total_retry_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3134
3135
3136
3137
3138
3139
3140
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 3134

def update!(**args)
  @backoff_retry_count = args[:backoff_retry_count] if args.key?(:backoff_retry_count)
  @id = args[:id] if args.key?(:id)
  @latest_err = args[:latest_err] if args.key?(:latest_err)
  @latest_retry_time = args[:latest_retry_time] if args.key?(:latest_retry_time)
  @total_retry_count = args[:total_retry_count] if args.key?(:total_retry_count)
end