Class: Google::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1Application
- Inherits:
-
Object
- Object
- Google::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1Application
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/beyondcorp_v1/classes.rb,
lib/google/apis/beyondcorp_v1/representations.rb,
lib/google/apis/beyondcorp_v1/representations.rb
Overview
The information about an application resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#endpoint_matchers ⇒ Array<Google::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1EndpointMatcher>
Optional.
-
#name ⇒ String
Identifier.
-
#schema ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#upstreams ⇒ Array<Google::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1ApplicationUpstream>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudBeyondcorpSecuritygatewaysV1Application
constructor
A new instance of GoogleCloudBeyondcorpSecuritygatewaysV1Application.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudBeyondcorpSecuritygatewaysV1Application
Returns a new instance of GoogleCloudBeyondcorpSecuritygatewaysV1Application.
1728 1729 1730 |
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 1728 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when the resource was created.
Corresponds to the JSON property createTime
1687 1688 1689 |
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 1687 def create_time @create_time end |
#display_name ⇒ String
Optional. An arbitrary user-provided name for the application resource. Cannot
exceed 64 characters.
Corresponds to the JSON property displayName
1693 1694 1695 |
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 1693 def display_name @display_name end |
#endpoint_matchers ⇒ Array<Google::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1EndpointMatcher>
Optional. An array of conditions to match the application's network endpoint.
Each element in the array is an EndpointMatcher object, which defines a
specific combination of a hostname pattern and one or more ports. The
application is considered matched if at least one of the EndpointMatcher
conditions in this array is met (the conditions are combined using OR logic).
Each EndpointMatcher must contain a hostname pattern, such as "example.com",
and one or more port numbers specified as a string, such as "443". Hostname
and port number examples: "*.example.com", "443" "example.com" and "22" "
example.com" and "22,33"
Corresponds to the JSON property endpointMatchers
1706 1707 1708 |
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 1706 def endpoint_matchers @endpoint_matchers end |
#name ⇒ String
Identifier. Name of the resource.
Corresponds to the JSON property name
1711 1712 1713 |
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 1711 def name @name end |
#schema ⇒ String
Optional. Type of the external application.
Corresponds to the JSON property schema
1716 1717 1718 |
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 1716 def schema @schema end |
#update_time ⇒ String
Output only. Timestamp when the resource was last modified.
Corresponds to the JSON property updateTime
1721 1722 1723 |
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 1721 def update_time @update_time end |
#upstreams ⇒ Array<Google::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1ApplicationUpstream>
Optional. Which upstream resources to forward traffic to.
Corresponds to the JSON property upstreams
1726 1727 1728 |
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 1726 def upstreams @upstreams end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1733 1734 1735 1736 1737 1738 1739 1740 1741 |
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 1733 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @endpoint_matchers = args[:endpoint_matchers] if args.key?(:endpoint_matchers) @name = args[:name] if args.key?(:name) @schema = args[:schema] if args.key?(:schema) @update_time = args[:update_time] if args.key?(:update_time) @upstreams = args[:upstreams] if args.key?(:upstreams) end |