Class: Google::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1ProxyProtocolConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/beyondcorp_v1/classes.rb,
lib/google/apis/beyondcorp_v1/representations.rb,
lib/google/apis/beyondcorp_v1/representations.rb

Overview

The configuration for the proxy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudBeyondcorpSecuritygatewaysV1ProxyProtocolConfig

Returns a new instance of GoogleCloudBeyondcorpSecuritygatewaysV1ProxyProtocolConfig.



2133
2134
2135
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2133

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_client_headersArray<String>

Optional. List of the allowed client header names. Corresponds to the JSON property allowedClientHeaders

Returns:

  • (Array<String>)


2107
2108
2109
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2107

def allowed_client_headers
  @allowed_client_headers
end

#client_ipBoolean Also known as: client_ip?

Optional. Client IP configuration. The client IP address is included if true. Corresponds to the JSON property clientIp

Returns:

  • (Boolean)


2112
2113
2114
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2112

def client_ip
  @client_ip
end

#contextual_headersGoogle::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1ContextualHeaders

Contextual headers configuration. Corresponds to the JSON property contextualHeaders



2118
2119
2120
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2118

def contextual_headers
  @contextual_headers
end

#gateway_identityString

Optional. The security gateway identity configuration. Corresponds to the JSON property gatewayIdentity

Returns:

  • (String)


2123
2124
2125
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2123

def gateway_identity
  @gateway_identity
end

#metadata_headersHash<String,String>

Optional. Custom resource specific headers along with the values. The names should conform to RFC 9110: >Field names can contain alphanumeric characters, hyphens, and periods, can contain only ASCII-printable characters and tabs, and must start with a letter. Corresponds to the JSON property metadataHeaders

Returns:

  • (Hash<String,String>)


2131
2132
2133
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2131

def 
  @metadata_headers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2138
2139
2140
2141
2142
2143
2144
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2138

def update!(**args)
  @allowed_client_headers = args[:allowed_client_headers] if args.key?(:allowed_client_headers)
  @client_ip = args[:client_ip] if args.key?(:client_ip)
  @contextual_headers = args[:contextual_headers] if args.key?(:contextual_headers)
  @gateway_identity = args[:gateway_identity] if args.key?(:gateway_identity)
  @metadata_headers = args[:metadata_headers] if args.key?(:metadata_headers)
end