Class: Google::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1SecurityGateway

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/beyondcorp_v1/classes.rb,
lib/google/apis/beyondcorp_v1/representations.rb,
lib/google/apis/beyondcorp_v1/representations.rb

Overview

The information about a security gateway resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudBeyondcorpSecuritygatewaysV1SecurityGateway

Returns a new instance of GoogleCloudBeyondcorpSecuritygatewaysV1SecurityGateway.



2210
2211
2212
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2210

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2154
2155
2156
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2154

def create_time
  @create_time
end

#delegating_service_accountString

Output only. Service account used for operations that involve resources in consumer projects. Corresponds to the JSON property delegatingServiceAccount

Returns:

  • (String)


2160
2161
2162
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2160

def 
  @delegating_service_account
end

#display_nameString

Optional. An arbitrary user-provided name for the SecurityGateway. Cannot exceed 64 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


2166
2167
2168
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2166

def display_name
  @display_name
end

#external_ipsArray<String>

Output only. IP addresses that will be used for establishing connection to the endpoints. Corresponds to the JSON property externalIps

Returns:

  • (Array<String>)


2172
2173
2174
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2172

def external_ips
  @external_ips
end

#hubsHash<String,Google::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1Hub>

Optional. Map of Hubs that represents regional data path deployment with GCP region as a key. Corresponds to the JSON property hubs



2178
2179
2180
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2178

def hubs
  @hubs
end

#loggingGoogle::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1LoggingConfig

Configuration for Cloud Logging. Corresponds to the JSON property logging



2183
2184
2185
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2183

def logging
  @logging
end

#nameString

Identifier. Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


2188
2189
2190
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2188

def name
  @name
end

#proxy_protocol_configGoogle::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1ProxyProtocolConfig

The configuration for the proxy. Corresponds to the JSON property proxyProtocolConfig



2193
2194
2195
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2193

def proxy_protocol_config
  @proxy_protocol_config
end

#service_discoveryGoogle::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1ServiceDiscovery

Settings related to the Service Discovery. Corresponds to the JSON property serviceDiscovery



2198
2199
2200
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2198

def service_discovery
  @service_discovery
end

#stateString

Output only. The operational state of the SecurityGateway. Corresponds to the JSON property state

Returns:

  • (String)


2203
2204
2205
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2203

def state
  @state
end

#update_timeString

Output only. Timestamp when the resource was last modified. Corresponds to the JSON property updateTime

Returns:

  • (String)


2208
2209
2210
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2208

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2215

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delegating_service_account = args[:delegating_service_account] if args.key?(:delegating_service_account)
  @display_name = args[:display_name] if args.key?(:display_name)
  @external_ips = args[:external_ips] if args.key?(:external_ips)
  @hubs = args[:hubs] if args.key?(:hubs)
  @logging = args[:logging] if args.key?(:logging)
  @name = args[:name] if args.key?(:name)
  @proxy_protocol_config = args[:proxy_protocol_config] if args.key?(:proxy_protocol_config)
  @service_discovery = args[:service_discovery] if args.key?(:service_discovery)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end