Class: Google::Apis::BeyondcorpV1::GoogleCloudBeyondcorpSecuritygatewaysV1alphaSecurityGatewayOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/beyondcorp_v1/classes.rb,
lib/google/apis/beyondcorp_v1/representations.rb,
lib/google/apis/beyondcorp_v1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudBeyondcorpSecuritygatewaysV1alphaSecurityGatewayOperationMetadata

Returns a new instance of GoogleCloudBeyondcorpSecuritygatewaysV1alphaSecurityGatewayOperationMetadata.



2389
2390
2391
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2389

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


2353
2354
2355
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2353

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2358
2359
2360
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2358

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


2363
2364
2365
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2363

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have been cancelled successfully have Operation. error value with a google.rpc.Status.code of 1, corresponding to Code. CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


2371
2372
2373
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2371

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


2377
2378
2379
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2377

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


2382
2383
2384
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2382

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


2387
2388
2389
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2387

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2394
2395
2396
2397
2398
2399
2400
2401
2402
# File 'lib/google/apis/beyondcorp_v1/classes.rb', line 2394

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end